@@ -1,6 +1,7 @@
 ;;;; -*- emacs-lisp -*-
 ;;;; GNU Mailutils -- a suite of utilities for electronic mail
-;;;; Copyright (C) 2003, 2007, 2010-2012 Free Software Foundation, Inc.
+;;;; Copyright (C) 2003, 2007, 2010-2012, 2014-2017 Free Software
+;;;; Foundation, Inc.
 ;;;; 
 ;;;; GNU Mailutils is free software; you can redistribute it and/or modify
 ;;;; it under the terms of the GNU General Public License as published by
@@ -18,5 +19,7 @@
 (setq mh-progs "/usr/bin")
 (setq mh-lib "/usr/share/mailutils/mh")
 (setq mh-lib-progs mh-progs)
+(load "mh-e")
+(setq mh-variant 'gnu-mh)
 
 ;;;; End of mailutils-mh.el
